@@ -1,5 +1,6 @@
 """Constants used by the Python V-ZUG API."""
 import pkg_resources
+from yarl import URL
 
 try:
     __version__ = pkg_resources.get_distribution("setuptools").version
@@ -9,9 +10,11 @@ except Exception:
 TIMEOUT = 10
 
 USER_AGENT = f"PythonVZUG/{__version__}"
-API = "/ai"
+API = URL("/ai")
+API2 = URL("/hh")
 
 DEVICE_STATUS = "getDeviceStatus"
+PROGRAM_STATUS = "getProgram"
 
 # Communication constants
 CONTENT_TYPE_JSON = "application/json"
